@@ -164,6 +164,29 @@ def init_repo(
     return is_new_repo
 
 
+def compare_branch(branch1: str, branch2: str, stat: bool = False):
+    """比较两个分支在文件层面的差异
+    :param branch1: 源分支
+    :param branch2: 目标分支，
+    :param stat: 仅返回统计信息
+    :return 返回branch1分支需要经过哪些变更才能与branch2分支一样
+    """
+    if stat:
+        return utils.execute_cmd(["git", "diff", branch1, branch2, "--stat"], level="debug")
+    else:
+        return utils.execute_cmd(["git", "diff", branch1, branch2], level="debug")
+
+
+def is_equal(branch1: str, branch2: str):
+    """检查两个对象【branch/tag/commit】在文件层面是否完全相等"""
+    res1 = compare_branch(branch1, branch2, stat=True)
+    res2 = compare_branch(branch2, branch1, stat=True)
+    if res1.stdout.strip() or res2.stdout.strip():
+        return False
+    else:
+        return True
+
+
 def pull_repo(
     repo_path: Union[str, Path],
     repo_url: str,
@@ -217,7 +240,8 @@ def pull_repo(
             branch_exist = check_branch_exist(repo_path, branch)
             if branch_exist:
                 # 本地存在指定分支时直接推送到远程，并建立跟踪
-                utils.execute_cmd(["git", "push", "-u", remote, branch])
+                utils.execute_cmd(["git", "push", "-u", remote, branch], level="info")
+                logger.info(f"远程库{repo_name}不存在{branch}分支，将本地的{branch}分支push到远程")
             else:
                 if no_exist_create_modle and no_exist_create_modle != branch:
                     # 本地不存在时基于模板分支创建指定分支
@@ -249,11 +273,11 @@ def pull_repo(
             utils.execute_cmd(["git", "fetch", remote, "tag", branch], level="debug")
         except Exception as _err:
             logger.exception(_err)
-            logger.error(f"拉取tag {branch}出错，删除本地{branch}后重试")
+            logger.error(f"拉取tag {branch}出错，删除本地{branch}后重新从远程拉取")
             # 出错后——通常是本地与远程tag不一致有冲突导致的
             # 冲突后删除本地重新从远程拉取
-            utils.execute_cmd(["git", "tag", "-d", branch], level="debug")
-            utils.execute_cmd(["git", "fetch", remote, "tag", branch], level="debug")
+            utils.execute_cmd(["git", "tag", "-d", branch], level="info")
+            utils.execute_cmd(["git", "fetch", remote, "tag", branch], level="info")
         utils.execute_cmd(["git", "checkout", branch], level="debug")
     elif branch_type == "commit":
         # 先检查本地是否已经为预计目标，如果是则不用访问远程git服务，防止远程git服务不可用导致额外的报错
