@@ -22,11 +22,11 @@ def get_current_time(
     now_time = datetime.datetime.now()
     target_time = now_time - datetime.timedelta(seconds=offset)
     if _format.lower() == "short":
-        return target_time.strftime("%Y-%m-%d")
+        return target_time.strftime(f"%Y{sep1}%m{sep1}%d")
     elif _format.lower() == "long":
-        return target_time.strftime("%Y-%m-%d %H:%M:%S")
+        return target_time.strftime(f"%Y{sep1}%m{sep1}%d %H{sep2}%M{sep2}%S")
     elif _format.lower() == "max":
-        return target_time.strftime("%Y-%m-%d %H:%M:%S.%f")
+        return target_time.strftime(f"%Y{sep1}%m{sep1}%d %H{sep2}%M{sep2}%S.%f")
     else:
         return target_time.strftime(_format)
 
